@@ -287,20 +287,22 @@ def import_petab_problem(
     :return:
         The imported model.
     """
+    # extract model name from pysb
+    if PysbPetabProblem and isinstance(petab_problem, PysbPetabProblem) \
+            and model_name is None:
+        model_name = petab_problem.pysb_model.name
+
     # generate folder and model name if necessary
     if model_output_dir is None:
         if PysbPetabProblem and isinstance(petab_problem, PysbPetabProblem):
             raise ValueError("Parameter `model_output_dir` is required.")
 
         model_output_dir = \
-            _create_model_output_dir_name(petab_problem.sbml_model)
+            _create_model_output_dir_name(petab_problem.sbml_model, model_name)
     else:
         model_output_dir = os.path.abspath(model_output_dir)
 
-    if PysbPetabProblem and isinstance(petab_problem, PysbPetabProblem) \
-            and model_name is None:
-        model_name = petab_problem.pysb_model.name
-    elif model_name is None:
+    if model_name is None:
         model_name = _create_model_name(model_output_dir)
 
     # create folder
@@ -374,7 +376,7 @@ def check_model(
         )
 
 
-def _create_model_output_dir_name(sbml_model: 'libsbml.Model') -> Path:
+def _create_model_output_dir_name(sbml_model: 'libsbml.Model', model_name: Optional[str] = None) -> Path:
     """
     Find a folder for storing the compiled amici model.
     If possible, use the sbml model id, otherwise create a random folder.
@@ -383,6 +385,10 @@ def _create_model_output_dir_name(sbml_model: 'libsbml.Model') -> Path:
     """
     BASE_DIR = Path("amici_models").absolute()
     BASE_DIR.mkdir(exist_ok=True)
+    # try model_name
+    if model_name:
+        return BASE_DIR / model_name
+
     # try sbml model id
     if sbml_model_id := sbml_model.getId():
         return BASE_DIR / sbml_model_id
@@ -430,6 +436,7 @@ def import_model_sbml(
         allow_reinit_fixpar_initcond: bool = True,
         validate: bool = True,
         non_estimated_parameters_as_constants=True,
+        output_parameter_defaults: Optional[Dict[str, float]] = None,
         **kwargs) -> amici.SbmlImporter:
     """
     Create AMICI model from PEtab problem
@@ -478,6 +485,11 @@ def import_model_sbml(
         model size and simulation times. If sensitivities with respect to those
         parameters are required, this should be set to ``False``.
 
+    :param output_parameter_defaults:
+        Optional default parameter values for output parameters introduced in
+        the PEtab observables table, in particular for placeholder parameters.
+        Dictionary mapping parameter IDs to default values.
+
     :param kwargs:
         Additional keyword arguments to be passed to
         :meth:`amici.sbml_import.SbmlImporter.sbml2amici`.
@@ -592,8 +604,20 @@ def import_model_sbml(
                 output_parameters[sym] = None
     logger.debug("Adding output parameters to model: "
                  f"{list(output_parameters.keys())}")
+    output_parameter_defaults = output_parameter_defaults or {}
+    if extra_pars := (set(output_parameter_defaults)
+                   - set(output_parameters.keys())):
+        raise ValueError(
+            f"Default output parameter values were given for {extra_pars}, "
+            "but they those are not output parameters."
+        )
+
     for par in output_parameters.keys():
-        _add_global_parameter(sbml_model, par)
+        _add_global_parameter(
+            sbml_model=sbml_model,
+            parameter_id=par,
+            value=output_parameter_defaults.get(par, 0.0)
+        )
     # <EndWorkAround>
 
     # TODO: to parameterize initial states or compartment sizes, we currently
@@ -825,6 +849,9 @@ def _parse_cli_args():
     parser.add_argument('--no-compile', action='store_false',
                         dest='compile',
                         help='Only generate model code, do not compile')
+    parser.add_argument('--no-validate', action='store_false',
+                        dest='validate',
+                        help='Skip validation of PEtab files')
     parser.add_argument('--flatten', dest='flatten', default=False,
                         action='store_true',
                         help='Flatten measurement specific overrides of '
@@ -863,7 +890,7 @@ def _parse_cli_args():
     return args
 
 
-def main():
+def _main():
     """
     Command line interface to import a model in the PEtab
     (https://github.com/PEtab-dev/PEtab/) format into AMICI.
@@ -881,7 +908,8 @@ def main():
             observable_files=args.observable_file_name)
 
     # Check for valid PEtab before potentially modifying it
-    petab.lint_problem(pp)
+    if args.validate:
+        petab.lint_problem(pp)
 
     if args.flatten:
         petab.flatten_timepoint_specific_output_overrides(pp)
@@ -899,4 +927,4 @@ def main():
 
 
 if __name__ == '__main__':
-    main()
+    _main()
