@@ -174,13 +174,16 @@ class SbmlImporter:
             sbml.L3P_MODULO_IS_PIECEWISE
         )
 
+    @log_execution_time('loading SBML', logger)
     def _process_document(self) -> None:
         """
         Validate and simplify document.
         """
         # Ensure we got a valid SBML model, otherwise further processing
         # might lead to undefined results
-        self.sbml_doc.validateSBML()
+        log_execution_time(f'validating SBML', logger)(
+            self.sbml_doc.validateSBML
+        )()
         _check_lib_sbml_errors(self.sbml_doc, self.show_sbml_warnings)
 
         # apply several model simplifications that make our life substantially
@@ -188,11 +191,15 @@ class SbmlImporter:
         if self.sbml_doc.getModel().getNumFunctionDefinitions():
             convert_config = sbml.SBMLFunctionDefinitionConverter()\
                 .getDefaultProperties()
-            self.sbml_doc.convert(convert_config)
+            log_execution_time(f'converting SBML functions', logger)(
+                self.sbml_doc.convert
+            )(convert_config)
 
         convert_config = sbml.SBMLLocalParameterConverter().\
             getDefaultProperties()
-        self.sbml_doc.convert(convert_config)
+        dec_fun = log_execution_time(f'converting SBML local parameters', logger)(
+            self.sbml_doc.convert
+        )(convert_config)
 
         # If any of the above calls produces an error, this will be added to
         # the SBMLError log in the sbml document. Thus, it is sufficient to
@@ -318,10 +325,10 @@ class SbmlImporter:
             case of stoichiometric coefficients with many significant digits.
 
         :param simplify:
-            see :attr:`ODEModel._simplify`
+            see :attr:`amici.ODEModel._simplify`
 
         :param cache_simplify:
-                see :func:`amici.ODEModel.__init__`
+                see :meth:`amici.ODEModel.__init__`
 
         :param log_as_log10:
             If ``True``, log in the SBML model will be parsed as ``log10``
@@ -2140,11 +2147,14 @@ def assignmentRules2observables(sbml_model: sbml.Model,
         })
     """
     observables = {}
-    for p in sbml_model.getListOfParameters():
-        parameter_id = p.getId()
-        if filter_function(p):
+    for rule in sbml_model.getListOfRules():
+        if rule.getTypeCode() != sbml.SBML_ASSIGNMENT_RULE:
+            continue
+        parameter_id = rule.getVariable()
+        if (p := sbml_model.getParameter(parameter_id)) \
+                and filter_function(p):
             observables[parameter_id] = {
-                'name': p.getName() if p.isSetName() else p.getId(),
+                'name': p.getName() if p.isSetName() else parameter_id,
                 'formula': sbml_model.getAssignmentRuleByVariable(
                     parameter_id
                 ).getFormula()
